/// <reference types="react" />
import type { TableProps } from '@itwin/itwinui-react';
import type { SourceFilesInfo, FileRecord } from './report-data-typings';
import './FilesTable.scss';
declare const defaultDisplayStrings: {
    failed: string;
    processed: string;
    processedWithIssues: string;
    fileName: string;
    status: string;
    path: string;
    fileID: string;
    datasource: string;
    mainFile: string;
};
/**
 * FilesTable should be shown when the files selection is active. It contains information about the processing and source of files.
 *
 * Localization is supported using the `displayStrings` prop, and custom icons can be specified using `fileTypeIcons` and `datasourceIcons`.
 * All of `Table` props from iTwinUI-react are also supported.
 */
export declare const FilesTable: ({ displayStrings: userDisplayStrings, sourceFilesInfo, fileRecords, fileTypeIcons: userFileTypeIcons, datasourceIcons, className, ...rest }: {
    sourceFilesInfo?: SourceFilesInfo | undefined;
    fileRecords?: FileRecord[] | undefined;
    displayStrings?: Partial<{
        failed: string;
        processed: string;
        processedWithIssues: string;
        fileName: string;
        status: string;
        path: string;
        fileID: string;
        datasource: string;
        mainFile: string;
    }> | undefined;
    /** Icons to show before the file names. */
    fileTypeIcons?: Record<string, JSX.Element> | undefined;
    /**
     * Custom icons to show in the dataSource column.
     * @example
     * datasourceIcons={{ 'iTwin File Service': <Svg>...</Svg> }}
     */
    datasourceIcons?: Record<string, JSX.Element> | undefined;
} & Partial<TableProps<Record<string, unknown>>>) => JSX.Element;
export {};
